Check the drug sig field; this is the verbatim instruction for the drug as written by the provider.
checkDrugSig(
cdm,
drugRecordsTable = "ingredient_drug_records",
byConcept = TRUE,
sampleSize = 10000
)a table with a summary of the sig values
CDMConnector reference object
a modified version of the drug exposure table, default "ingredient_drug_records"
whether to get result by drug concept
the sample size given in execute checks