View the results in the Shiny app
viewResults(
dataFolder,
makePublishable = FALSE,
publishDir = file.path(getwd(), "ResultsExplorer"),
overwritePublishDir = FALSE,
launch.browser = FALSE
)A folder where the exported zip files with the results are stored. Zip files containing results from multiple databases can be placed in the same folder.
(Optional) copy data files to make app publishable to posit connect/shinyapp.io
If make publishable is true - the directory that the shiny app is copied to
(Optional) If make publishable is true - overwrite the directory for publishing
Should the app be launched in your default browser, or in a Shiny window. Note: copying to clipboard will not work in a Shiny window.
Launches a Shiny app that allows the user to explore the diagnostics