Check if Days_supply is the same as datediff(drug_exp_start_date,drug_exp_end_date)
checkDaysSupply(
cdm,
drugRecordsTable = "ingredient_drug_records",
byConcept = TRUE,
sampleSize = 10000
)a table with the stats of days supply compared to start and end date
CDMConnector reference object
a modified version of the drug exposure table, default "ingredient_drug_records"
whether to get result by drug concept
the sample size given in execute checks