Get a summary of the daily drug dose
checkDrugDose(cdm, ingredientConceptId, sampleSize = NULL, minCellCount = 5)a table with the stats about the daily dose
CDMConnector reference object
ingredient
Maximum number of records of an ingredient to estimate dose
coverage. If an ingredient has more, a random sample equal to sampleSize
will be considered. If NULL, all records will be used.
minimum number of events to report- results lower than this will be obscured. If NULL all results will be reported.